@@ -1,25 +1,27 @@
-from zope.interface import implements
+from Products.membrane.interfaces.events import IMembraneTypeRegisteredEvent
+from Products.membrane.interfaces.events import IMembraneTypeUnregisteredEvent
+from zope.interface import implementer
 
-from interfaces import IMembraneTypeRegisteredEvent
-from interfaces import IMembraneTypeUnregisteredEvent
 
-class MembraneTypeEvent(object):
+class MembraneTypeEvent:
     """
     Base class for membrane type related events.
     """
+
     def __init__(self, tool, portal_type):
         self.tool = tool
         self.portal_type = portal_type
 
+
+@implementer(IMembraneTypeRegisteredEvent)
 class MembraneTypeRegisteredEvent(MembraneTypeEvent):
     """
     A membrane type has been registered.
     """
-    implements(IMembraneTypeRegisteredEvent)
 
+
+@implementer(IMembraneTypeUnregisteredEvent)
 class MembraneTypeUnregisteredEvent(MembraneTypeEvent):
     """
     A membrane type has been registered.
     """
-    implements(IMembraneTypeUnregisteredEvent)
-
