@@ -1,47 +1,47 @@
 from AccessControl import ClassSecurityInfo
-from App.class_init import InitializeClass
-from Products.PageTemplates.PageTemplateFile import PageTemplateFile
-
-from Products.PlonePAS.plugins.ufactory import PloneUserFactory, PloneUser
-
+from AccessControl.class_init import InitializeClass
 from Products.CMFCore.utils import getToolByName
-
-from Products.membrane.interfaces.user import IMembraneUser
-from Products.membrane.interfaces.plugins import IMembraneUserFactoryPlugin
 from Products.membrane.config import TOOLNAME
+from Products.membrane.interfaces.plugins import IMembraneUserFactoryPlugin
+from Products.membrane.interfaces.user import IMembraneUser
+from Products.PageTemplates.PageTemplateFile import PageTemplateFile
+from Products.PlonePAS.plugins.ufactory import PloneUser
+from Products.PlonePAS.plugins.ufactory import PloneUserFactory
+from zope.interface import implementer
 
-from zope.interface import implements
 
 manage_addMembraneUserFactoryForm = PageTemplateFile(
-    '../www/MembraneUserFactoryForm', globals(),
-    __name__='manage_addMembraneUserFactoryForm' )
+    "../www/MembraneUserFactoryForm",
+    globals(),
+    __name__="manage_addMembraneUserFactoryForm",
+)
 
 
 def addMembraneUserFactory(dispatcher, id, title=None, REQUEST=None):
-    """ Add a MembraneUserFactory to a Pluggable Auth Service. """
+    """Add a MembraneUserFactory to a Pluggable Auth Service."""
 
     pmm = MembraneUserFactory(id, title)
     dispatcher._setObject(pmm.getId(), pmm)
 
     if REQUEST is not None:
-        REQUEST['RESPONSE'].redirect(
-                                '%s/manage_workspace'
-                                '?manage_tabs_message='
-                                'MembraneUserFactory+added.'
-                            % dispatcher.absolute_url())
+        REQUEST["RESPONSE"].redirect(
+            "%s/manage_workspace"
+            "?manage_tabs_message="
+            "MembraneUserFactory+added." % dispatcher.absolute_url()
+        )
 
 
+@implementer(IMembraneUserFactoryPlugin)
 class MembraneUserFactory(PloneUserFactory):
 
     security = ClassSecurityInfo()
-    meta_type = 'Membrane User Factory'
+    meta_type = "Membrane User Factory"
 
-    implements(IMembraneUserFactoryPlugin)
-
-    def __init__(self, id, title=''):
+    def __init__(self, id, title=""):
         self.id = id
         self.title = title or self.meta_type
 
+    @security.private
     def createUser(self, user_id, name):
         mbtool = getToolByName(self, TOOLNAME)
         # don't create the user unless it's a membrane-based user
@@ -50,24 +50,24 @@ class MembraneUserFactory(PloneUserFactory):
         if not mbtool.case_sensitive_auth:
             user_id = mbtool.getOriginalUserIdCase(user_id)
         return MembraneUser(user_id, name)
-    security.declarePrivate('createUser')
+
 
 InitializeClass(MembraneUserFactory)
 
-_marker = ['INVALID_VALUE']
+_marker = ["INVALID_VALUE"]
 
 
+@implementer(IMembraneUser)
 class MembraneUser(PloneUser):
 
     security = ClassSecurityInfo()
 
-    implements(IMembraneUser)
-
     #
     # Implementing getProperty for convenience
     # This is also implemented by the wrapper
     # from memberdata...
     #
+    @security.private
     def getProperty(self, name, default=_marker):
         """getProperty(self, name) => return property value or
         raise AttributeError
@@ -79,15 +79,14 @@ class MembraneUser(PloneUser):
             raise AttributeError(name)
         else:
             return default
-    security.declarePrivate("getProperty")
 
+    @security.private
     def hasProperty(self, name):
         """hasProperty"""
         for sheet in self.getOrderedPropertySheets():
             if sheet.hasProperty(name):
                 True
         return False
-    security.declarePrivate("hasProperty")
 
 
 InitializeClass(MembraneUser)
